@@ -5,10 +5,10 @@ function(x, ...){
 		mode.mat[i,1] <- x$model.modes[i]-x$mode.sd[i]
 		mode.mat[i,2] <- x$model.modes[i]+x$mode.sd[i]
 		}
-	if(dim(x$prior.data)[2] == 3){
+	if(dim(x$prior.fit)[2] == 3){
 		par(mar=c(5,5,4,2)+0.3) #changes left margin to make large labels fit
-		plot(x$prior.data$theta.vals, x$prior.data$ds.prior, 
-			main = "MacroInference: Modes", type = "l", yaxs = "i", lwd = 2, col = "red3",
+		plot(x$prior.fit$theta.vals, x$prior.fit$ds.prior, 
+			type = "l", yaxs = "i", lwd = 2, col = "red3",
 			xlab = expression(theta), ylab = "", font.main = 1,
 			cex.lab=1.45, cex.axis=1.5, cex.main=2, cex.sub=1.5, ...)
 		title(ylab = expression(paste(hat(pi)(theta))), line = 2.3, cex.lab=1.45)
@@ -19,8 +19,8 @@ function(x, ...){
 			}
 		} else {
 		par(mar=c(5,5,4,2)+0.3) #changes left margin to make large labels fit
-		plot(x$prior.data$theta.vals, x$prior.data$parm.prior, 
-			main = "MacroInference: Modes", type = "l", yaxs = "i", lwd = 2, col = "red3",
+		plot(x$prior.fit$theta.vals, x$prior.fit$parm.prior, 
+			type = "l", yaxs = "i", lwd = 2, col = "red3",
 			xlab = expression(theta), ylab = "", font.main = 1,
 			cex.lab=1.45, cex.axis=1.5, cex.main=2, cex.sub=1.5, ...)
 		title(ylab = expression(paste(hat(pi)(theta))), line = 2.3, cex.lab=1.45)
